# v0.2.0 (2024-07-11)

## New features

- `itertools` collection of iterators that are focused on processing (byte) streams of information collected from subprocesses. This includes basic support for simple pipe-like processing stream, including splitting off, and rejoining certain items in such a stream. These tools extend and interoperate with standard Python utilities for iterables, such as the built-in `itertools`, and the `more_itertools` package. [[3175cafe]](https://github.com/datalad/datasalad/commit/3175cafe)

## Documentation

- show off new features on the frontpage [[751e5bf9]](https://github.com/datalad/datasalad/commit/751e5bf9)
- update project metadata [[72ecde84]](https://github.com/datalad/datasalad/commit/72ecde84)


# v0.1.0 (2024-06-14)

## New features

- `iter_subproc()` utility
- `iterable_subprocess()` utility
- `CommandError` exception

# v0.0.1rc2 (2024-05-14)

- Non-functional test release

# v0.0.1rc1 (2024-05-13)

- Non-functional test release
